<template>
  <div class="common-page-content">
    <div class="common-search-container" ref="contentPanel">
      <el-form
        ref="form"
        :model="searchForm"
        label-width="80"
        label-position="right "
        :inline="true"
        type="flex"
        justify="left"
      >
        <el-form-item label="模板编码">
          <el-input
            size="small"
            v-model="searchForm.code"
            clearable
            placeholder="请输入模板编码"
          ></el-input>
        </el-form-item>
        <el-form-item label="模板名称">
          <el-input
            size="small"
            v-model="searchForm.name"
            clearable
            placeholder="请输入模板名称"
          ></el-input>
        </el-form-item>
      </el-form>
      <div class="container-btn">
        <el-button
          size="small"
          icon="el-icon-search"
          type="danger"
          class="btn btn-plus"
          @click="handleSearch"
        >
          搜索
        </el-button>
        <el-button
          size="small"
          icon="el-icon-refresh-right"
          class="btn btn-plus"
          @click="clearSearchForm"
        >
          重置
        </el-button>
      </div>
    </div>
    <el-row
      class="common-table-container flex searchPanel"
      :style="SearchPanel"
    >
      <el-col :span="24" class="common-table-wrapper">
        <div class="common-btn-group">
          <el-button
            size="small"
            icon="el-icon-plus"
            type="primary"
            class="btn btn-plus"
            @click="handleAdd"
          >
            新增
          </el-button>
          <el-button
            size="small"
            slot="reference"
            icon="el-icon-delete"
            type="danger"
            class="btn btn-delete"
            @click="handleDelete"
          >
            {{ this.$t('common.delete') }}
          </el-button>
        </div>
        <!-- LJ：表格高度自适应需配合样式  btn-pagenation 有按钮有分页  btngroup只有按钮  pagenation只有分页 -->
        <div class="common-table-content  btn-pagenation">
          <el-table
            :border="true"
            stripe
            fit
            size="mini"
            height="100%"
            v-loading="tableLoading"
            ref="multipleSelection"
            :max-height="tableMaxHeight"
            :data="tableData"
            @row-dblclick="handleDetail"
          >
            <el-table-column type="selection" min-width="5%" align="center">
            </el-table-column>
            <el-table-column
              prop="code"
              min-width="20%"
              label="模板编号"
              align="center"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="name"
              show-overflow-tooltip
              min-width="20%"
              align="center"
              label="模板名称"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="preparedOrgName"
              show-overflow-tooltip
              min-width="20%"
              align="center"
              label="编制公司"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="targetType"
              show-overflow-tooltip
              min-width="20%"
              align="center"
              label="项目类型"
              resizable
            >
            <template slot-scope="scope">
              <div v-if="scope.row.targetType==1">
                  物资
              </div>
              <div v-if="scope.row.targetType==2">
                  项目
              </div>
            </template>
            </el-table-column>
            <el-table-column
              prop="quotationMethod"
              show-overflow-tooltip
              min-width="20%"
              align="center"
              label="报价方式"
              resizable
            >
            <template v-slot="{row}">
                {{ getDictName('cglx-fkfs', row.quotationMethod) }}
              </template>
            </el-table-column>
            <el-table-column
              prop="isTax"
              show-overflow-tooltip
              min-width="20%"
              align="center"
              label="是否含税价"
              resizable
            >
            <template v-slot="{row}">
                {{ getDictName('cglx-jjfs', row.isTax) }}
              </template>
            </el-table-column>
            <el-table-column
              prop="remarks"
              show-overflow-tooltip
              min-width="20%"
              align="center"
              label="模板说明"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="dataQuoteStatus"
              show-overflow-tooltip
              min-width="10%"
              align="center"
              label="引用状态"
              resizable
            >
            <template v-slot="{row}">
                <span v-if="row.dataQuoteStatus == 0">未引用</span>
                <span v-if="row.dataQuoteStatus == 1">已引用</span>
              </template>
            </el-table-column>
            <el-table-column min-width="15%" align="center" label="操作">
              <template v-slot="{row}">
                <template>
                  <el-button
                    icon="el-icon-edit"
                    type="primary"
                    plain
                    v-if="row.dataQuoteStatus == 0"
                    size="small"
                    @click="handleEdit(row)"
                    >编辑</el-button
                  >
                </template>
              </template>
            </el-table-column>
          </el-table>
        </div>
        <div class="common-pagenation">
          <el-pagination
            ref="paginationPanel"
            background
            @size-change="handleSizeChange"
            @current-change="handleCurrentChange"
            :current-page="pageResult.page"
            :page-sizes="[20, 30, 40, 50]"
            :page-size="pageResult.pageSize"
            layout="total, sizes, prev, pager, next, jumper"
            :total="pageResult.total"
          >
          </el-pagination>
        </div>
      </el-col>
    </el-row>
  </div>
</template>

<script>
import pagination from '@/components/pagination'
import {TableMixin} from '@/mixins/tableMixin'
import supplierManger from '@/api/supplierManger.js'
import req from '@/request.js'
import utils from '@/utils.js'
const portal = window.context.portal
export default {
  name: 'DemandEntry',
  components: {
    pagination
  },
  mixins: [TableMixin],
  data() {
    return {
      currentPage: 1,
      loading: false,
      tableLoading: false,
      tableData: [],
      multipleSelection: [],
      params: {
        pageBean: {
          page: 1,
          pageSize: 20,
          total: 0
        }
      },
      queryParam: {
        pageBean: {
          page: 1,
          pageSize: 20,
          total: 0
        }
      },
      searchForm: {}, // 顶部搜索对象
      deleteIds: '', // 是否选中列表解锁删除按钮
      activeCollapse1: ['1', '2'],
      fileList: [], // 文件上传
      edit: false, // 是否是修改功能
      currentDataDel: [], // 删除时排查是否有在审核的数据 
    }
  },
  mounted() {},
  created() {
    if (this.$route.params.pageBean) {
      this.params = this.$route.params.pageBean
      this.pageResult = this.$route.params.pageBean.pageBean
    }
    this.loadData(this.params)
  },
  methods: {
    getDictName(code, value) {
      return utils.getDictName(code, value)
    },
    //获取数据
    loadData() {
      this.tableLoading = true
      this.$http.post('${portal}/quotationTemplate/v1/page',this.params).then(res=>{
        this.tableLoading = false
        const data = (res && res.data) || {}
        this.tableData = data.value.rows || []
        this.pageResult = {
          page: data.value.page,
          pageSize: data.value.pageSize,
          total: data.value.total
        }
      })
    },
    //添加
    handleAdd() {
      this.$router.push({
        path: `/quoteTemplateAddDialog`
      })
    },
    // 编辑
    handleEdit(rows) {
      this.$refs.form.clearValidate()
      this.$router.push({
        name: 'quoteTemplateAddDialog',
        query: {editRows: rows}
      })
    },
    // 详情
    handleDetail(rows) {
      this.$router.push({
        name: 'quoteTemplateDetail',
        query: {editRows: rows}
      })
    },

    // 删除
    handleDelete() {
      let selection = this.$refs.multipleSelection.selection
      if (selection.length === 0) {
        this.$alert('请选择要删除的数据！', this.$t('common.tips'), {
          confirmButtonText: this.$t('common.confirm'),
          type: 'warning'
        })
      } else {
        let ids = []
        selection.forEach(item => {
          let str =  item.id
          ids.push(str)
        })
        this.$confirm(this.$t('common.sureDelete'), this.$t('common.tips'), {
          confirmButtonText: this.$t('common.confirm'),
          cancelButtonText: this.$t('common.cancel'),
          type: 'warning'
        }).then(() => {
          this.tableLoading = true
          this.$http.remove('${portal}/quotationTemplate/v1/'+ids).then(res=>{
            console.log(res,'resss');
            this.tableLoading = false
            if (res.data.state) {
              this.$message.success('删除成功！')
              this.handleSearch()
            } else {
              this.$message.error('删除失败！')
            }
          })
        })
      }
    },
    //重置
    clearSearchForm() {
      this.searchForm = {}
      this.handleSearch()
    },
    // 顶部搜索
    handleSearch() {
      let obj = this.searchForm
      let querys = []
      for (let i in obj) {
        if (obj[i]) {
          querys.push({
            group: 'main',
            operation: i == 'name' || i == 'code' ? 'LIKE' : 'EQUAL',
            parentGroup: '',
            property: i,
            relation: 'AND',
            value: obj[i]
          })
        }
      }

      this.params.querys = querys
      this.loadData(this.params)
    },
    handleCurrentChange(page) {
      this.params.pageBean = {...this.params.pageBean, page}
      this.loadData(this.params)
    },
    handleSizeChange(pageSize) {
      this.params.pageBean = {...this.params.pageBean, pageSize}
      this.loadData(this.params)
    }
  },
  computed: {
    SearchPanel() {
      return {
        '--searchPanel': this.searchPanel + 'px'
      }
    }
  }
}
</script>

<style lang="scss" scoped>
.cloumn-btn {
  border: 1px solid #2761ff;
  padding: 3px 10px;
  border-radius: 5px;
  &:nth-child(1) {
    margin-right: 5px;
  }
  &:nth-child(2) {
    margin-right: 5px;
  }
  &:nth-child(1):hover {
    background-color: #2761ff;
    color: #fff;
  }
  &:nth-child(2):hover {
    background-color: #2761ff;
    color: #fff;
  }
  /deep/ i,
  span {
    font-size: 16px;
  }
}

/deep/ .el-tree-node__content {
  padding: 5px 0;
}

/deep/ .el-table thead tr th {
  background-color: #eee !important;
  border-right: 1px solid #dfe2e8 !important;
}
/deep/ .el-table {
  border-collapse: collapse !important;
}
</style>
